# Enable HTMX Navigation on NetBox User Preferences.

> If not enabled, this will cause visual bugs on Proxbox GUI. For more details, [check this issue](https://github.com/netdevopsbr/netbox-proxbox/issues/277).

Go to **/user/preferences** path and change enable HTMX navigation like below:

![image](https://github.com/user-attachments/assets/f29d13c1-4933-4e25-b97b-81b5f3e76fe7)